"""This creates a templates guid file from the core metadata archive"""

import argparse
import os
import sys
import time
from typing import Union

import nest_asyncio
from rich import box
from rich.console import Console
from rich.prompt import Prompt
from rich.table import Table
from textual.widgets import DataTable

from pyegeria import (
    AutomatedCuration,
    InvalidParameterException,
    PropertyServerException,
    UserNotAuthorizedException,
    print_exception_response,
)

console = Console()
EGERIA_METADATA_STORE = os.environ.get("EGERIA_METADATA_STORE", "active-metadata-store")
EGERIA_KAFKA_ENDPOINT = os.environ.get("KAFKA_ENDPOINT", "localhost:9092")
EGERIA_PLATFORM_URL = os.environ.get("EGERIA_PLATFORM_URL", "https://localhost:9443")
EGERIA_VIEW_SERVER = os.environ.get("EGERIA_VIEW_SERVER", "view-server")
EGERIA_VIEW_SERVER_URL = os.environ.get(
    "EGERIA_VIEW_SERVER_URL", "https://localhost:9443"
)
EGERIA_INTEGRATION_DAEMON = os.environ.get("EGERIA_INTEGRATION_DAEMON", "integration-daemon")
EGERIA_ADMIN_USER = os.environ.get("ADMIN_USER", "garygeeke")
EGERIA_ADMIN_PASSWORD = os.environ.get("ADMIN_PASSWORD", "secret")
EGERIA_USER = os.environ.get("EGERIA_USER", "erinoverview")
EGERIA_USER_PASSWORD = os.environ.get("EGERIA_USER_PASSWORD", "secret")
EGERIA_JUPYTER = bool(os.environ.get("EGERIA_JUPYTER", "False"))
EGERIA_WIDTH = int(os.environ.get("EGERIA_WIDTH", "200"))


def list_templates(
    search_string: str, server: str, url: str, username: str, password: str
) -> []:
    """Return a list of templates for one or more technology type"""
    a_client = AutomatedCuration(server, url, username)
    token = a_client.create_egeria_bearer_token(username, password)
    tech_list = a_client.find_technology_types(search_string, page_size=0)
    tech_info_list: dict = []

    if type(tech_list) is list:
        for item in tech_list:
            if "deployedImplementationType" not in item["qualifiedName"]:
                continue

            details = a_client.get_tech_type_detail(item["name"])
            entry = {details["name"]: {}}
            if type(details) is str:
                tech_info_list.append(entry)
                continue
            templates = details.get("catalogTemplates", "Not Found")
            if type(templates) is list:
                t_list = []
                entry = {details["name"]: {}}
                for template in templates:
                    t_list.append({"template": template["name"]})
                entry[details["name"]] = t_list
                tech_info_list.append(entry)
    return tech_info_list


def add_row(
    table: Union[Table, DataTable],
    name: str,
    template_name: str,
    template_guid: str,
    placeholder_table: Table,
) -> Table | DataTable:
    if isinstance(table, Table):
        table.add_row(name, template_name, template_guid, placeholder_table)
    elif isinstance(table, DataTable):
        table.add_row(name, template_name, template_guid, placeholder_table)

    return table


def display_templates_spec(
    search_string: str,
    server: str,
    url: str,
    username: str,
    password: str,
    jupyter: bool = EGERIA_JUPYTER,
    width: int = EGERIA_WIDTH,
    data_table: bool = False,
) -> Table | DataTable:
    a_client = AutomatedCuration(server, url, username)
    nest_asyncio.apply()
    token = a_client.create_egeria_bearer_token(username, password)
    tech_list = a_client.find_technology_types(search_string, page_size=0)

    def generate_table(data_table: bool) -> Table | DataTable:
        """Make a new table."""
        if data_table:
            table = DataTable()
            table.add_columns("Name", "Template Name", "Template GUID", "Placeholders")
        else:
            table = Table(
                title=f"Technology Templates for: {url} @ {time.asctime()}",
                style="bold bright_white on black",
                row_styles=["bold bright_white on black"],
                header_style="white on dark_blue",
                title_style="bold bright_white on black",
                caption_style="white on black",
                show_lines=True,
                box=box.ROUNDED,
                caption=f"Templates from Server '{server}' @ Platform - {url}",
                expand=True,
                # width=500
            )

            table.add_column("Name", width=20)
            table.add_column("Template Name", width=20)
            table.add_column("Template GUID", width=38, no_wrap=True)
            table.add_column("Placeholders")

        if type(tech_list) is list:
            for item in tech_list:
                if "deployedImplementationType" not in item["qualifiedName"]:
                    continue
                placeholder_table = Table(expand=False, show_lines=True)
                placeholder_table.add_column("Name", width=20, no_wrap=True)
                placeholder_table.add_column("Type", width=10)
                placeholder_table.add_column("Required", width=10)
                placeholder_table.add_column("Example", width=20)
                placeholder_table.add_column("Description", width=40)

                name = item.get("name", "none")

                details = a_client.get_tech_type_detail(name)
                if type(details) is str:
                    console.log(f"Missing details for - {name}: {details}")
                    continue

                templates = details.get("catalogTemplates", "Not Found")
                if type(templates) is not str:
                    for template in templates:
                        template_name = template.get("name", None)

                        template_name = (
                            f"{name}_Template"
                            if template_name is None
                            else template_name
                        )

                        specification = template["specification"]["placeholderProperty"]
                        template_guid = template["relatedElement"]["guid"]

                        for placeholder in specification:
                            placeholder_data_type = placeholder["dataType"]
                            placeholder_description = placeholder["description"]
                            placeholder_name = placeholder["placeholderPropertyName"]
                            placeholder_required = placeholder["required"]
                            placeholder_example = placeholder.get("example", None)
                            placeholder_table.add_row(
                                placeholder_name,
                                placeholder_data_type,
                                placeholder_required,
                                placeholder_example,
                                placeholder_description,
                            )

                        # table.add_row(name, template_name, template_guid, placeholder_table)
                        table = add_row(
                            table, name, template_name, template_guid, placeholder_table
                        )

            return table
        else:
            print("Unknown technology type")
            sys.exit(1)

    try:
        if data_table:
            return generate_table(data_table)
        else:
            console = Console(width=width, force_terminal=not jupyter)

            with console.pager(styles=True):
                console.print(generate_table(data_table))

    except (
        InvalidParameterException,
        PropertyServerException,
        UserNotAuthorizedException,
    ) as e:
        print_exception_response(e)
        assert e.related_http_code != "200", "Invalid parameters"
    finally:
        a_client.close_session()


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("--server", help="Name of the server to display status for")
    parser.add_argument("--url", help="URL Platform to connect to")
    parser.add_argument("--userid", help="User Id")
    parser.add_argument("--password", help="Password")

    args = parser.parse_args()

    server = args.server if args.server is not None else EGERIA_VIEW_SERVER
    url = args.url if args.url is not None else EGERIA_PLATFORM_URL
    userid = args.userid if args.userid is not None else EGERIA_USER
    password = args.password if args.password is not None else EGERIA_USER_PASSWORD
    guid = None

    try:
        search_string = Prompt.ask(
            "Enter the technology you are searching for:", default="*"
        )
        display_templates_spec(
            search_string, server, url, userid, password, data_table=False
        )
    except KeyboardInterrupt:
        pass


# def display_templates_spec(
#     search_string: str,
#     server: str,
#     url: str,
#     username: str,
#     password: str,
#     jupyter: bool = EGERIA_JUPYTER,
#     width: int = EGERIA_WIDTH,
# ):
#     a_client = AutomatedCuration(server, url, username)
#     token = a_client.create_egeria_bearer_token(username, password)
#     tech_list = a_client.find_technology_types(search_string, page_size=0)
#
#     def generate_table() -> Table:
#         """Make a new table."""
#         table = Table(
#             title=f"Technology Templates for: {url} @ {time.asctime()}",
#             style="bold bright_white on black",
#             row_styles=["bold bright_white on black"],
#             header_style="white on dark_blue",
#             title_style="bold bright_white on black",
#             caption_style="white on black",
#             show_lines=True,
#             box=box.ROUNDED,
#             caption=f"Templates from Server '{server}' @ Platform - {url}",
#             expand=True,
#             # width=500
#         )
#
#         table.add_column("Name", width=20)
#         table.add_column("Template Name", width=20)
#         table.add_column("Template GUID", width=38, no_wrap=True)
#         table.add_column("Placeholders")
#
#         if type(tech_list) is list:
#             for item in tech_list:
#                 if "deployedImplementationType" not in item["qualifiedName"]:
#                     continue
#                 placeholder_table = Table(expand=False, show_lines=True)
#                 placeholder_table.add_column("Name", width=20, no_wrap=True)
#                 placeholder_table.add_column("Type", width=10)
#                 placeholder_table.add_column("Required", width=10)
#                 placeholder_table.add_column("Example", width=20)
#                 placeholder_table.add_column("Description", width=40)
#
#                 name = item.get("name", "none")
#
#                 details = a_client.get_tech_type_detail(name)
#                 if type(details) is str:
#                     console.log(f"Missing details for - {name}: {details}")
#                     continue
#
#                 templates = details.get("catalogTemplates", "Not Found")
#                 if type(templates) is not str:
#                     for template in templates:
#                         template_name = template.get("name", None)
#
#                         template_name = (
#                             f"{name}_Template"
#                             if template_name is None
#                             else template_name
#                         )
#
#                         specification = template["specification"]["placeholderProperty"]
#                         template_guid = template["relatedElement"]["guid"]
#
#                         for placeholder in specification:
#                             placeholder_data_type = placeholder["dataType"]
#                             placeholder_description = placeholder["description"]
#                             placeholder_name = placeholder["placeholderPropertyName"]
#                             placeholder_required = placeholder["required"]
#                             placeholder_example = placeholder.get("example", None)
#                             placeholder_table.add_row(
#                                 placeholder_name,
#                                 placeholder_data_type,
#                                 placeholder_required,
#                                 placeholder_example,
#                                 placeholder_description,
#                             )
#
#                         table.add_row(
#                             name, template_name, template_guid, placeholder_table
#                         )
#
#             return table
#         else:
#             print("Unknown technology type")
#             sys.exit(1)
#
#     try:
#         console = Console(width=width, force_terminal=not jupyter)
#
#         with console.pager(styles=True):
#             console.print(generate_table())
#
#     except (
#         InvalidParameterException,
#         PropertyServerException,
#         UserNotAuthorizedException,
#     ) as e:
#         print_exception_response(e)
#         assert e.related_http_code != "200", "Invalid parameters"
#     finally:
#         a_client.close_session()
#
#
# def main():
#     parser = argparse.ArgumentParser()
#     parser.add_argument("--server", help="Name of the server to display status for")
#     parser.add_argument("--url", help="URL Platform to connect to")
#     parser.add_argument("--userid", help="User Id")
#     parser.add_argument("--password", help="Password")
#
#     args = parser.parse_args()
#
#     server = args.server if args.server is not None else EGERIA_VIEW_SERVER
#     url = args.url if args.url is not None else EGERIA_PLATFORM_URL
#     userid = args.userid if args.userid is not None else EGERIA_USER
#     password = args.password if args.password is not None else EGERIA_USER_PASSWORD
#     guid = None
#
#     try:
#         search_string = Prompt.ask(
#             "Enter the technology you are searching for:", default="*"
#         )
#         # display_templates_spec(search_string, server, url, userid, password)
#         list_templates(search_string, server, url, userid, password)
#     except KeyboardInterrupt:
#         pass
#
#
# if __name__ == "__main__":
#     main()



"""
SPDX-License-Identifier: Apache-2.0
Copyright Contributors to the ODPi Egeria project.

Runtime manager is a view service that supports user interaction with the running platforms.

"""
from pyegeria.automated_curation import AutomatedCuration
from pyegeria.classification_manager import ClassificationManager
from pyegeria.data_designer import DataDesigner
from pyegeria.egeria_cat_client import EgeriaCat
from pyegeria.metadata_explorer_omvs import MetadataExplorer
from pyegeria.registered_info import RegisteredInfo
from pyegeria.runtime_manager_omvs import RuntimeManager
from pyegeria.solution_architect import SolutionArchitect
from pyegeria.template_manager_omvs import TemplateManager
from pyegeria.valid_metadata_omvs import ValidMetadataManager
from pyegeria.governance_officer import GovernanceOfficer
from pyegeria.collection_manager import CollectionManager
from pyegeria.external_links import ExternalReferences
from pyegeria._globals import NO_ELEMENTS_FOUND

class EgeriaTech:
    """
    Client for technical Egeria users using composition.

    Attributes:
        view_server: str
            Name of the view server to use.
        platform_url : str
            URL of the server platform to connect to
        user_id : str
            The identity of the user calling the method.
        user_pwd: str
            The password associated with the user_id. Defaults to None
        token: str, optional
            Bearer token

    Methods:
        Methods are provided by composed sub-clients via delegation.
    """

    def __init__(
        self,
        view_server: str,
        platform_url: str,
        user_id: str,
        user_pwd: str = None,
        token: str = None,
    ):
        self.view_server = view_server
        self.platform_url = platform_url
        self.user_id = user_id
        self.user_pwd = user_pwd

        # Compose sub-clients
        self._auto_curate = AutomatedCuration(view_server, platform_url, user_id, user_pwd, token)
        self._cat = EgeriaCat(view_server, platform_url, user_id, user_pwd, token)
        self._class_mgr = ClassificationManager(view_server, platform_url, user_id, user_pwd, token)
        self._reg_info = RegisteredInfo(view_server, platform_url, user_id, user_pwd, token)
        self._runtime = RuntimeManager(view_server, platform_url, user_id, user_pwd, token)
        self._valid = ValidMetadataManager(view_server, platform_url, user_id, user_pwd, token)
        self._explorer = MetadataExplorer(view_server, platform_url, user_id, user_pwd, token)
        self._sol_arch = SolutionArchitect(view_server, platform_url, user_id, user_pwd, token)
        self._designer = DataDesigner(view_server, platform_url, user_id, user_pwd, token)
        self._templates = TemplateManager(view_server, platform_url, user_id, user_pwd, token)
        self._gov_officer = GovernanceOfficer(view_server, platform_url, user_id, user_pwd, token)
        self._collections = CollectionManager(view_server, platform_url, user_id, user_pwd, token)
        self._external_references = ExternalReferences(view_server, platform_url, user_id, user_pwd, token)
        self._classification_manager = ClassificationManager(view_server, platform_url, user_id, user_pwd, token)


        self._subclients = [
            self._auto_curate,
            self._cat,
            self._class_mgr,
            self._reg_info,
            self._runtime,
            self._valid,
            self._explorer,
            self._sol_arch,
            self._designer,
            self._templates,
            self._gov_officer,
            self._collections,
            self._external_references,
            self._classification_manager
        ]
        self.NO_ELEMENTS_FOUND = NO_ELEMENTS_FOUND

    def __getattr__(self, name):
        for sub in self._subclients:
            if hasattr(sub, name):
                return getattr(sub, name)
        raise AttributeError(f"{self.__class__.__name__!s} object has no attribute {name!r}")

    def create_egeria_bearer_token(self, user_id: str = None, user_pwd: str = None):
        token_val = None
        for sub in self._subclients:
            token_val = sub.create_egeria_bearer_token(user_id, user_pwd)
        return token_val

    def set_bearer_token(self, token: str) -> None:
        for sub in self._subclients:
            sub.set_bearer_token(token)

    def get_token(self) -> str:
        for sub in self._subclients:
            if hasattr(sub, "get_token"):
                return sub.get_token()
        return None

    def close_session(self) -> None:
        for sub in self._subclients:
            if hasattr(sub, "close_session"):
                try:
                    sub.close_session()
                except Exception:
                    pass

if __name__ == "__main__":
    print("Main-Tech Client")



"""
SPDX-License-Identifier: Apache-2.0
Copyright Contributors to the ODPi Egeria project.

Unit tests for the Utils helper functions using the Pytest framework.

"""

import json
from contextlib import nullcontext as does_not_raise

import pytest
import asyncio
from loguru import logger

from pyegeria import print_basic_exception
from pyegeria._client_new import Client2
from pyegeria._exceptions_new import (
     PyegeriaException, PyegeriaConnectionException,  PyegeriaInvalidParameterException,
     PyegeriaAPIException, PyegeriaUnknownException, PyegeriaClientException, PyegeriaNotFoundException,
    PyegeriaUnauthorizedException,
    )


@pytest.fixture()
def basic_server():
    platform = "https://127.0.0.1:9443"


class TestClient:
    # @pytest.mark.xfail
    @pytest.mark.parametrize(
        "url, user_id, status_code, expectation",
        [
            (
                "https://google.com",
                "garygeeke",
                404,
                pytest.raises(PyegeriaClientException),
            ),
            (
                    "https://localhost:9443",
                    "garygeeke",
                    200,
                    does_not_raise(),
                    ),
            (
                "https://127.0.0.1:30081",
                "garygeeke",
                404,
                pytest.raises(PyegeriaConnectionException),
            ),
            (
                "https://127.0.0.1:9443",
                "garygeeke",
                200,
                does_not_raise(),
            ),
            (
                "https://127.0.0.1:9443/open-metadata/admin-services/users/meow/servers/active-metadata-store",
                "meow",
                401,
                pytest.raises(PyegeriaClientException),
            ),
            (
                "https://cray.local:9443/open-metadata/admin-services/users/woof/servers/active-metadata-store",
                "garygeeke",
                404,
                pytest.raises(PyegeriaConnectionException),
            ),
            ("", "", 400, pytest.raises(PyegeriaInvalidParameterException)),
            ],
        )
    def test_get_origin(self, url, user_id, status_code, expectation):
        server = 'qs-view-server'
        with expectation as excinfo:
            client = Client2(server, url, user_id)
            response = client.get_platform_origin()
            if response:
                assert response, "Successfully called get_platform_origin()"
            else:
                assert response, "Failed to call get_platform_origin()"
        # if excinfo:
        #     logger.error(excinfo.value)


    def test_make_get_request(self, url, user_id, status_code, expectation):
        server = "None"
        user_pwd = "nonesuch"
        response = ""
        with expectation as excinfo:
            t_client = Client2(server, url, user_id, user_pwd)
            endpoint = (
                    url
                    + "/open-metadata/admin-services/users/"
                    + user_id
                    + "/stores/connection"
            )
            if t_client is not None:
                response = t_client.make_request("GET", endpoint, None)
                assert response is not None, "There was only an exception response"
        if excinfo:
            logger.error(excinfo.value)
        else:
            if (response is not None) & (response.status_code is None):
                assert excinfo.value.http_error_code == str(status_code), "Invalid URL"

            else:
                assert response.status_code == status_code, "Invalid URL"

    def test_refresh_egeria_bearer_token(self):
        c = Client2(
            "qs-metadata-store", "https://localhost:9443", "erinoverview", "secret"
            )
        token = c.create_egeria_bearer_token()
        token2 = c.refresh_egeria_bearer_token()
        if type(token2) == str:
            print(f"The token returned is \n{token}")
        elif type(token2) is dict:
            print(f"The returned token is dict:\n{json.dumps(token2, indent=2)}")

    def test_get_guid(self):
        """This doesn't work since the method needs to be called from an omvs based class"""
        c = Client2(
            "qs-view-server", "https://localhost:9443", "erinoverview", "secret"
            )
        try:
            c.create_egeria_bearer_token()
            display_name = "PostgreSQL Server"
            qname = None
            guid = None
            property_name = "displayName"
            response = c.__get_guid__(guid, display_name, property_name, qname)
            if type(response) == str:
                print(f"The response returned is \n{response}")
        except PyegeriaException as e:
            print_basic_exception(e)
            assert False, "Invalid request"

    def test_get_guid(self):
        c = Client2(
            "qs-view-server", "https://localhost:9443", "erinoverview", "secret"
        )
        try:
            c.create_egeria_bearer_token()
            display_name = "PostgreSQL Server"
            type_name = "ValidMetadataValue"
            property_name = ["displayName"]
            response = c.get_guid_for_name( display_name, property_name, type_name)
            # response = c.get_elements_by_property_value(display_name, property_name, type_name)
            if type(response) == str:
                print(f"The response returned is \n{response}")
            if isinstance(response, list | dict):
                print(json.dumps(response, indent=2))
        except PyegeriaException as e:
            print_basic_exception(e)
            assert False, "Invalid request"


if __name__ == "__main__":
    print("something")



#!/usr/bin/env python3
"""
SPDX-License-Identifier: Apache-2.0
Copyright Contributors to the ODPi Egeria project.

A simple viewer for collections - provide the root and we display the hierarchy

"""

import argparse
import os

from rich import print
from rich.panel import Panel
from rich.prompt import Prompt
from rich.text import Text
from rich.tree import Tree

from pyegeria import (
    CollectionManager,
    InvalidParameterException,
    PropertyServerException,
    UserNotAuthorizedException, NO_ELEMENTS_FOUND,
    )
from pyegeria._exceptions import print_exception_response

disable_ssl_warnings = True
EGERIA_METADATA_STORE = os.environ.get("EGERIA_METADATA_STORE", "active-metadata-store")
EGERIA_KAFKA_ENDPOINT = os.environ.get("KAFKA_ENDPOINT", "localhost:9092")
EGERIA_PLATFORM_URL = os.environ.get("EGERIA_PLATFORM_URL", "https://localhost:9443")
EGERIA_VIEW_SERVER = os.environ.get("EGERIA_VIEW_SERVER", "view-server")
EGERIA_VIEW_SERVER_URL = os.environ.get(
    "EGERIA_VIEW_SERVER_URL", "https://localhost:9443"
)
EGERIA_INTEGRATION_DAEMON = os.environ.get("EGERIA_INTEGRATION_DAEMON", "integration-daemon")
EGERIA_ADMIN_USER = os.environ.get("ADMIN_USER", "garygeeke")
EGERIA_ADMIN_PASSWORD = os.environ.get("ADMIN_PASSWORD", "secret")
EGERIA_USER = os.environ.get("EGERIA_USER", "erinoverview")
EGERIA_USER_PASSWORD = os.environ.get("EGERIA_USER_PASSWORD", "secret")
EGERIA_JUPYTER = bool(os.environ.get("EGERIA_JUPYTER", "False"))
EGERIA_WIDTH = int(os.environ.get("EGERIA_WIDTH", "200"))


def collection_viewer(
    root: str,
    server_name: str,
    platform_url: str,
    user: str,
    user_password: str,
    jupyter: bool = EGERIA_JUPYTER,
    width: int = EGERIA_WIDTH,
):
    """A simple collection viewer"""

    def walk_collection_hierarchy(
        tree: Tree,
        collection_client: CollectionManager,
        root_collection_guid: str = None,
        root_collection_name: str = None,
        root_collection_qname: str = None,
    ) -> None:
        """Recursively build a Tree with collection contents."""
        members = collection_client.get_member_list(
            root_collection_guid, root_collection_name, root_collection_qname
        )
        if type(members) is list:
            for member in members:
                style = "bold white on black"
                text_collection_name = Text(
                    f"[bold white on black]Name: {member['name']}", style=style
                )
                text_qualified_name = Text(
                    f"* QualifiedName: {member['qualifiedName']}"
                )
                text_guid = Text(f"* GUID: {member['guid']}", "green")
                text_collection_type = Text(
                    f"* Collection Type: {member['collectionType']}"
                )
                text_description = Text(f"* Description: {member['description']}")
                p = Panel.fit(
                    f"{text_collection_name}[green]\n{text_qualified_name}\n{text_guid}\n"
                    f"{text_collection_type}\n{text_description}"
                )
                tt = tree.add(p, style=style)

                children = collection_client.get_collection_members(
                    collection_guid=member["guid"]
                )
                if type(children) is list:
                    branch = tt.add(
                        f"[bold magenta on black]Members",
                        style=style,
                        guide_style=style,
                    )
                    walk_collection_hierarchy(branch, collection_client, member["guid"])
        else:
            tt = tree.add(
                f"[bold magenta on black]No collections found in {root_collection_name}"
            )

    try:
        tree = Tree(f"[bold bright green]{root}", guide_style="bold bright_blue")
        c_client = CollectionManager(server_name, platform_url, user_id=user)

        token = c_client.create_egeria_bearer_token(user, user_password)
        walk_collection_hierarchy(tree, c_client, None, root)
        print(tree)

    except (
        InvalidParameterException,
        PropertyServerException,
        UserNotAuthorizedException,
    ) as e:
        if e.exception_error_message_parameters[1] == NO_ELEMENTS_FOUND:
            print("The collection was not found.")
        else:
            print_exception_response(e)
    finally:
        c_client.close_session()


def main():
    parser = argparse.ArgumentParser()

    parser.add_argument("--server", help="Name of the server to display status for")
    parser.add_argument("--url", help="URL Platform to connect to")
    parser.add_argument("--userid", help="User Id")
    parser.add_argument("--password", help="User Password")
    args = parser.parse_args()

    server = args.server if args.server is not None else EGERIA_VIEW_SERVER
    url = args.url if args.url is not None else EGERIA_PLATFORM_URL
    userid = args.userid if args.userid is not None else EGERIA_USER
    user_pass = args.password if args.password is not None else EGERIA_USER_PASSWORD

    try:
        root_collection = Prompt.ask(
            "Enter the Root Collection to start from:",
            default="Digital Products Root",
        )
        collection_viewer(root_collection, server, url, userid, user_pass)
    except KeyboardInterrupt:
        pass


if __name__ == "__main__":
    main()



"""
SPDX-License-Identifier: Apache-2.0
Copyright Contributors to the ODPi Egeria project.
"""

"""
This common file is used to set some global values and enumerations used by the overall package. 

"""


is_debug = False
disable_ssl_warnings = True
enable_ssl_check = False
max_paging_size = 500
default_time_out = 30
DEBUG_LEVEL = "quiet"
COMMENT_TYPES = (
    "STANDARD_COMMENT",
    "ANSWER",
    "OTHER",
    "QUESTION",
    "SUGGESTION",
    "USAGE_EXPERIENCE",
    "REQUIREMENT"
)
star_ratings = (
    "FIVE_STARS",
    "FOUR_STARS",
    "NO_RECOMMENDATION",
    "ONE_STAR",
    "THREE_STARS",
    "TWO_STARS",
)

TEMPLATE_GUIDS: dict = {}
INTEGRATION_GUIDS: dict = {}

NO_ELEMENTS_FOUND = "No elements found"
NO_ASSETS_FOUND = "No assets found"
NO_SERVERS_FOUND = "No servers found"
NO_CATALOGS_FOUND = "No catalogs found"
NO_GLOSSARIES_FOUND = "No glossaries found"
NO_TERMS_FOUND = "No terms found"
NO_CATEGORIES_FOUND = "No categories found"
NO_ELEMENT_FOUND = "No element found"
NO_PROJECTS_FOUND = "No projects found"
NO_COLLECTION_FOUND = "No collection found"
NO_GUID_RETURNED = "No guid returned"
NO_MEMBERS_FOUND = "No members found"

MERMAID_GRAPHS = ["anchorMermaidGraph", "informationSupplyChainMermaidGraph","fieldLevelLineageGraph",
                  "actionMermaidGraph", "localLineageGraph", "edgeMermaidGraph", "iscImplementationMermaidGraph",
                  "specificationMermaidGraph", "solutionBlueprintMermaidGraph","mermaidGraph",
                  "solutionSubcomponentMermaidGraph"]
MERMAID_GRAPH_TITLES = ["Anchor Mermaid Graph", "Information Supply Chain Mermaid Graph","Field Level Lineage Graph",
                  "Action Mermaid Graph", "Local Lineage Graph", "Edge Mermaid Graph", "ISC Implementation Mermaid Graph",
                  "Specification Mermaid Graph", "Solution Blueprint Mermaid Graph","Mermaid Graph",
                  "Solution Subcomponent Mermaid Graph"]

#
# TEMPLATE_GUIDS['File System Directory'] = 'c353fd5d-9523-4a5e-a5e2-723ae490fe54'
# INTEGRATION_GUIDS['GeneralFilesMonitor'] = '1b98cdac-dd0a-4621-93db-99ef5a1098bc'
# INTEGRATION_GUIDS['OpenLineageFilePublisher'] = '6271b678-7d22-4cdf-87b1-45b366beaf4e'
# INTEGRATION_GUIDS['ContentPacksMonitor'] = '6bb2181e-7724-4515-ba3c-877cded55980'
# INTEGRATION_GUIDS['HarvestActivity'] = '856501d9-ec29-4e67-9cd7-120f53710ffa'
# INTEGRATION_GUIDS['SampleDataFilesMonitor'] = 'cd6479e1-2fe7-4426-b358-8a0cf70be117'
# TEMPLATE_GUIDS['CSV Data File'] = '13770f93-13c8-42be-9bb8-e0b1b1e52b1f'
# TEMPLATE_GUIDS['Keystore File'] = 'fbcfcc0c-1652-421f-b49b-c3e1c108768f'
# TEMPLATE_GUIDS['Unity Catalog Registered Model Version'] = '1364bfe7-8295-4e99-9243-8840aeac4cf1'
# TEMPLATE_GUIDS['Unity Catalog Server'] = 'dcca9788-b30f-4007-b1ac-ec634aff6879'
# INTEGRATION_GUIDS['UnityCatalogInsideCatalog'] = '74dde22f-2249-4ea3-af2b-b39e73f79b81'
# INTEGRATION_GUIDS['UnityCatalogServer'] = '06d068d9-9e08-4e67-8c59-073bbf1013af'
# TEMPLATE_GUIDS['Databricks Unity Catalog Server'] = '3f7f62f6-4abc-424e-9f92-523306e7d5d5'
# INTEGRATION_GUIDS['JDBC'] = '70dcd0b7-9f06-48ad-ad44-ae4d7a7762aa'
# TEMPLATE_GUIDS['Data File'] = '66d8dda9-00cf-4e59-938c-4b0583596b1e'
# TEMPLATE_GUIDS['Unity Catalog Catalog'] = '5ee006aa-a6d6-411b-9b8d-5f720c079cae'
# TEMPLATE_GUIDS['View Server'] = 'fd61ca01-390d-4aa2-a55d-426826aa4e1b'
# TEMPLATE_GUIDS['Archive File'] = '7578e504-d00f-406d-a194-3fc0a351cdf9'
# TEMPLATE_GUIDS['Executable File'] = '3d99a163-7a13-4576-a212-784010a8302a'
# INTEGRATION_GUIDS['OpenLineageAPIPublisher'] = '2156bc98-973a-4859-908d-4ccc96f53cc5'
# TEMPLATE_GUIDS['PostgreSQL Relational Database'] = '3d398b3f-7ae6-4713-952a-409f3dea8520'
# INTEGRATION_GUIDS['PostgreSQLDatabase'] = 'ef301220-7dfe-4c6c-bb9d-8f92d9f63823'
# TEMPLATE_GUIDS['Unity Catalog Table'] = '6cc1e5f5-4c1e-4290-a80e-e06643ffb13d'
# TEMPLATE_GUIDS['JSON Data File'] = 'c4836635-7e9e-446a-83b5-15e206b1aff3'
# TEMPLATE_GUIDS['File System'] = '522f228c-097c-4f90-9efc-26c1f2696f87'
# TEMPLATE_GUIDS['Source Code File'] = '9c7013ef-f29b-4b01-a8ea-5ea14f64c67a'
# TEMPLATE_GUIDS['Program File'] = '32d27e9c-1fdf-455a-ad2a-42b4d7d99108'
# TEMPLATE_GUIDS['Apple MacBook Pro'] = '32a9fd56-85c9-47fe-a211-9da3871bf4da'
# TEMPLATE_GUIDS['Build Instruction File'] = 'fbb2fa2e-8bcb-402e-9be7-5c6db9f2c504'
# TEMPLATE_GUIDS['Spreadsheet Data File'] = 'e4fabff5-2ba9-4050-9076-6ed917970b4c'
# TEMPLATE_GUIDS['UNIX File System'] = '27117270-8667-41d0-a99a-9118f9b60199'
# TEMPLATE_GUIDS['Video Data File'] = '93b2b722-ec0f-4da4-960a-b8d4922f8bf5'
# TEMPLATE_GUIDS['JDBC Endpoint'] = '3d79ce50-1887-4627-ad71-ba4649aba2bc'
# TEMPLATE_GUIDS['Unity Catalog Function'] = 'a490ba65-6104-4213-9be9-524e16fed8aa'
# TEMPLATE_GUIDS['Unity Catalog Registered Model'] = '0d762ec5-c1f5-4364-aa64-e7e00d27f837'
# TEMPLATE_GUIDS['PostgreSQL Relational Database Schema'] = '82a5417c-d882-4271-8444-4c6a996a8bfc'
# INTEGRATION_GUIDS['HarvestSurveys'] = 'fae162c3-2bfd-467f-9c47-2e3b63a655de'
# INTEGRATION_GUIDS['HarvestActivity'] = '856501d9-ec29-4e67-9cd7-120f53710ffa'
# INTEGRATION_GUIDS['HarvestOpenMetadata'] = 'f8bf326b-d613-4ece-a12e-a1423bc272d7'
# TEMPLATE_GUIDS['PostgreSQL Server'] = '542134e6-b9ce-4dce-8aef-22e8daf34fdb'
# INTEGRATION_GUIDS['PostgreSQLServer'] = '36f69fd0-54ba-4f59-8a44-11ccf2687a34'
# TEMPLATE_GUIDS['Audio Data File'] = '39b4b670-7f15-4744-a5ba-62e8edafbcee'
# TEMPLATE_GUIDS['Document File'] = 'eb6f728d-fa54-4350-9807-1199cbf96851'
# TEMPLATE_GUIDS['Engine Host'] = '1764a891-4234-45f1-8cc3-536af40c790d'
# TEMPLATE_GUIDS['Integration Daemon'] = '6b3516f0-dd13-4786-9601-07215f995197'
# TEMPLATE_GUIDS['XML Data File'] = 'ea67ae71-c674-473e-b38b-689879d2a7d9'
# TEMPLATE_GUIDS['Avro Data File'] = '9f5be428-058e-41dd-b506-3a222283b579'
# TEMPLATE_GUIDS['REST API Endpoint'] = '9ea4bff4-d193-492f-bcad-6e68c07c6f9e'
# TEMPLATE_GUIDS['Unity Catalog Schema'] = '5bf92b0f-3970-41ea-b0a3-aacfbf6fd92e'
# TEMPLATE_GUIDS['Unity Catalog Volume'] = '92d2d2dc-0798-41f0-9512-b10548d312b7'
# TEMPLATE_GUIDS['Parquet Data File'] = '7f6cd744-79c3-4d25-a056-eeb1a91574c3'
# TEMPLATE_GUIDS['File'] = 'ae3067c7-cc72-4a18-88e1-746803c2c86f'
# TEMPLATE_GUIDS['3D Image Data File'] = '0059ea2b-6292-4cac-aa6f-a80a605f1114'
# TEMPLATE_GUIDS['YAML File'] = '2221855b-2b64-4b45-a2ee-c40adc5e2a64'
# TEMPLATE_GUIDS['Apache Kafka Topic'] = 'ea8f81c9-c59c-47de-9525-7cc59d1251e5'
# INTEGRATION_GUIDS['OpenLineageKafkaListener'] = '980b989c-de78-4e6a-a58d-51049d7381bf'
# TEMPLATE_GUIDS['Script File'] = 'dbd5e6bb-1ff8-46f4-a007-fb0485f68c92'
# TEMPLATE_GUIDS['Apache Atlas Server'] = 'fe6dce45-a978-4417-ab55-17f05b8bcea7'
# INTEGRATION_GUIDS['ApacheAtlasServer'] = '5721627a-2dd4-4f95-a274-6cfb128edb97'
# TEMPLATE_GUIDS['Raster Data File'] = '47211156-f03f-4881-8526-015e695a3dac'
# TEMPLATE_GUIDS['Metadata Access Server'] = 'bd8de890-fa79-4c24-aab8-20b41b5893dd'
# TEMPLATE_GUIDS['Data Folder'] = '372a0379-7060-4c9d-8d84-bc709b31794c'
# INTEGRATION_GUIDS['MaintainDataFolderLastUpdateDate'] = 'fd26f07c-ae44-4bc5-b457-37b43112224f'
# INTEGRATION_GUIDS['OpenLineageFilePublisher'] = '6271b678-7d22-4cdf-87b1-45b366beaf4e'
# TEMPLATE_GUIDS['Properties File'] = '3b281111-a0ef-4fc4-99e7-9a0ef84a7636'
# TEMPLATE_GUIDS['Vector Data File'] = 'db1bec7f-55a9-40d3-91c0-a57b76d422e2'
# TEMPLATE_GUIDS['OMAG Server Platform'] = '9b06c4dc-ddc8-47ae-b56b-28775d3a96f0'
# INTEGRATION_GUIDS['OpenAPI'] = 'b89d9a5a-2ea6-49bc-a4fc-e7df9f3ca93e'
# INTEGRATION_GUIDS['OMAGServerPlatform'] = 'dee84e6e-7a96-4975-86c1-152fb3ab759b'
# TEMPLATE_GUIDS['Apache Kafka Server'] = '5e1ff810-5418-43f7-b7c4-e6e062f9aff7'
# INTEGRATION_GUIDS['KafkaTopic'] = 'fa1f711c-0b34-4b57-8e6e-16162b132b0c'
# INTEGRATION_GUIDS['OpenLineageAPIPublisher'] = '2156bc98-973a-4859-908d-4ccc96f53cc5'
# INTEGRATION_GUIDS['JDBCDatabaseCataloguer'] = '70dcd0b7-9f06-48ad-ad44-ae4d7a7762aa'
# INTEGRATION_GUIDS['ApacheKafkaCataloguer'] = 'fa1f711c-0b34-4b57-8e6e-16162b132b0c'
# INTEGRATION_GUIDS['FilesCataloguer'] = '1b98cdac-dd0a-4621-93db-99ef5a1098bc'
# INTEGRATION_GUIDS['UnityCatalogServerSynchronizer'] = '06d068d9-9e08-4e67-8c59-073bbf1013af'
# INTEGRATION_GUIDS['SampleDataCataloguer'] = 'cd6479e1-2fe7-4426-b358-8a0cf70be117'
# INTEGRATION_GUIDS['OpenLineageGovernanceActionPublisher'] = '206f8faf-04da-4b6f-8280-eeee3943afeb'
# INTEGRATION_GUIDS['OMAGServerPlatformCataloguer'] = 'dee84e6e-7a96-4975-86c1-152fb3ab759b'
# INTEGRATION_GUIDS['HarvestActivity'] = '856501d9-ec29-4e67-9cd7-120f53710ffa'
# INTEGRATION_GUIDS['MaintainLastUpdateDate'] = 'fd26f07c-ae44-4bc5-b457-37b43112224f'
# INTEGRATION_GUIDS['UnityCatalogInsideCatalogSynchronizer'] = '74dde22f-2249-4ea3-af2b-b39e73f79b81'
# INTEGRATION_GUIDS['OpenLineageKafkaListener'] = '980b989c-de78-4e6a-a58d-51049d7381bf'
# INTEGRATION_GUIDS['HarvestOpenMetadata'] = 'f8bf326b-d613-4ece-a12e-a1423bc272d7'
# INTEGRATION_GUIDS['OpenAPICataloguer'] = 'b89d9a5a-2ea6-49bc-a4fc-e7df9f3ca93e'
# INTEGRATION_GUIDS['OpenLineageFilePublisher'] = '6271b678-7d22-4cdf-87b1-45b366beaf4e'
# INTEGRATION_GUIDS['PostgreSQLServerCataloguer'] = '36f69fd0-54ba-4f59-8a44-11ccf2687a34'
# INTEGRATION_GUIDS['PostgreSQLDatabaseCataloguer'] = 'ef301220-7dfe-4c6c-bb9d-8f92d9f63823'
# INTEGRATION_GUIDS['ContentPacksCataloguer'] = '6bb2181e-7724-4515-ba3c-877cded55980'
# INTEGRATION_GUIDS['OpenLineageCataloguer'] = '3347ac71-8dd2-403a-bc16-75a71be64bd7'
# INTEGRATION_GUIDS['ApacheAtlasExchange'] = '5721627a-2dd4-4f95-a274-6cfb128edb97'
# INTEGRATION_GUIDS['HarvestSurveys'] = 'fae162c3-2bfd-467f-9c47-2e3b63a655de'



#!/usr/bin/env python3
"""
SPDX-License-Identifier: Apache-2.0
Copyright Contributors to the ODPi Egeria project.

Display the status of cataloged platforms and servers.
"""
import argparse
import os

from rich import print
from rich.console import Console
from rich.markdown import Markdown
from rich.panel import Panel
from rich.prompt import Prompt
from rich.tree import Tree

from pyegeria import (
    AutomatedCuration,
    InvalidParameterException,
    PropertyServerException,
    UserNotAuthorizedException,
    print_exception_response,
)

EGERIA_METADATA_STORE = os.environ.get("EGERIA_METADATA_STORE", "active-metadata-store")
EGERIA_KAFKA_ENDPOINT = os.environ.get("KAFKA_ENDPOINT", "localhost:9092")
EGERIA_PLATFORM_URL = os.environ.get("EGERIA_PLATFORM_URL", "https://localhost:9443")
EGERIA_VIEW_SERVER = os.environ.get("EGERIA_VIEW_SERVER", "view-server")
EGERIA_VIEW_SERVER_URL = os.environ.get(
    "EGERIA_VIEW_SERVER_URL", "https://localhost:9443"
)
EGERIA_INTEGRATION_DAEMON = os.environ.get("EGERIA_INTEGRATION_DAEMON", "integration-daemon")
EGERIA_ADMIN_USER = os.environ.get("ADMIN_USER", "garygeeke")
EGERIA_ADMIN_PASSWORD = os.environ.get("ADMIN_PASSWORD", "secret")
EGERIA_USER = os.environ.get("EGERIA_USER", "erinoverview")
EGERIA_USER_PASSWORD = os.environ.get("EGERIA_USER_PASSWORD", "secret")
EGERIA_JUPYTER = bool(os.environ.get("EGERIA_JUPYTER", "False"))
EGERIA_WIDTH = int(os.environ.get("EGERIA_WIDTH", "200"))


disable_ssl_warnings = True
console = Console(width=200)

guid_list = []


def template_viewer(
    tech_name: str,
    server_name: str,
    platform_url: str,
    user: str,
    user_pass: str,
    jupyter: bool = EGERIA_JUPYTER,
    width: int = EGERIA_WIDTH,
):
    def build_classifications(classification: dict) -> Markdown:
        class_md = "\n"
        for c in classification:
            c_type = c["classificationName"]
            if c_type == "Anchors":
                continue
            class_md += f"* Classification: {c_type}\n"
            class_props = c.get("classificationProperties", None)
            if class_props is None:
                continue
            for prop in class_props.keys():
                class_md += f"\t* {prop}: {class_props[prop]}\n"
        if class_md == "-":
            output = None
        else:
            output = class_md
        return output

    try:
        console = Console(width=width, force_terminal=not jupyter)

        a_client = AutomatedCuration(server_name, platform_url, user_id=user)

        token = a_client.create_egeria_bearer_token(user, user_pass)
        tech_elements = a_client.get_technology_type_elements(
            tech_name, get_templates=True
        )
        if (len(tech_elements) >= 1) and (type(tech_elements) is list):
            tree = Tree(
                f"Deployed Technology Type: {tech_name}",
                style="bold bright_white",
                guide_style="bold bright_blue",
            )
            note: str = " "
            for element in tech_elements:
                header = element["elementHeader"]
                tech_type = header["type"]["typeName"]
                tech_collection = header["origin"]["homeMetadataCollectionName"]
                tech_created_by = header["versions"]["createdBy"]
                tech_created_at = header["versions"]["createTime"]
                tech_guid = header["guid"]
                tech_classifications = header["classifications"]
                class_md = build_classifications(tech_classifications)

                referenceables = element["referenceableProperties"]
                tech_qualified_name = referenceables["qualifiedName"]
                extended = referenceables["extendedProperties"]
                ex_md: str = ""
                for key, value in extended.items():
                    ex_md += f"* {key}: {value}\n"

                note = (
                    f"* Qualified Name: {tech_qualified_name}\n"
                    f"* GUID: {tech_guid}\n"
                    f"* Createdy by: {tech_created_by}\n"
                    f"* Created at: {tech_created_at}\n"
                    f"* Home Collection: {tech_collection}\n"
                    f"{class_md}\n"
                    f"{ex_md}\n"
                )

                interfaces = extended.get("connectorInterfaces", None)
                if interfaces is not None:
                    interface_type_name = interfaces["typeName"]
                    interface_array_cnt = interfaces["arrayCount"]
                    note += f"* Interface Type: {interface_type_name}\n"
                    for i in range(0, int(interface_array_cnt)):
                        note += (
                            f"\t* Type: {interfaces['arrayValues']['propertyValueMap'][str(i)]['typeName']}"
                            f"\tName: {interfaces['arrayValues']['propertiesAsStrings'][str(i)]}\n"
                        )
                note_md = Panel.fit(Markdown(note), style="bold bright_white on black")
                t = tree.add(note_md)

        else:
            tree = Tree(f"No elements found for {tech_name}", style="red")
        print(tree)
    except (
        InvalidParameterException,
        PropertyServerException,
        UserNotAuthorizedException,
    ) as e:
        print_exception_response(e)


def main():
    parser = argparse.ArgumentParser()

    parser.add_argument("--server", help="Name of the server to display status for")
    parser.add_argument("--url", help="URL Platform to connect to")
    parser.add_argument("--userid", help="User Id")
    parser.add_argument("--password", help="User Password")
    args = parser.parse_args()

    server = args.server if args.server is not None else EGERIA_VIEW_SERVER
    url = args.url if args.url is not None else EGERIA_PLATFORM_URL
    userid = args.userid if args.userid is not None else EGERIA_USER
    user_pass = args.password if args.password is not None else EGERIA_USER_PASSWORD

    try:
        tech_name = Prompt.ask(
            "Enter the Asset Name to view:", default="Apache Kafka Server"
        )
        template_viewer(tech_name, server, url, userid, user_pass)
    except KeyboardInterrupt:
        pass


if __name__ == "__main__":
    main()



"""
SPDX-License-Identifier: Apache-2.0
Copyright Contributors to the ODPi Egeria project.

Egeria Coco Pharmaceutical demonstration labs.

Configuring cocoMDS1 - Data Lake Operations metadata server

"""

import json

from globals import adminUserId, cocoCohort, cocoMDS1Name, dataLakePlatformURL

from pyegeria import CoreServerConfig, Platform, print_exception_response

mdr_server = cocoMDS1Name
platform_url = dataLakePlatformURL
admin_user = adminUserId
mdr_server_user_id = "cocoMDS1npa"
mdr_server_password = "cocoMDS1passw0rd"
metadataCollectionId = f"{mdr_server}-e915f2fa-aa3g-4396-8bde-bcd65e642b1d"
metadataCollectionName = "Data Lake Catalog"

max_page_size = 600

print("Configuring " + mdr_server + "..." + " @ " + platform_url)

try:
    o_client = CoreServerConfig(mdr_server, platform_url, admin_user)

    o_client.set_basic_server_properties(
        "Data lake operations",
        "Coco Pharmaceuticals",
        platform_url,
        mdr_server_user_id,
        mdr_server_password,
        max_page_size,
        mdr_server,
    )

    # Can also inherit event bus config from application properties

    event_bus_config = {
        "producer": {"bootstrap.servers": "{{kafkaEndpoint}}"},
        "consumer": {"bootstrap.servers": "{{kafkaEndpoint}}"},
    }

    o_client.set_event_bus(event_bus_config)

    security_connection_body = {
        "class": "Connection",
        "connectorType": {
            "class": "ConnectorType",
            "connectorProviderClassName": "org.odpi.openmetadata.metadatasecurity.samples.CocoPharmaServerSecurityProvider",
        },
    }
    o_client.set_xtdb_local_kv_repository()
    # o_client.set_in_mem_local_repository()
    o_client.add_default_log_destinations()
    o_client.set_server_security_connection(security_connection_body)
    o_client.set_local_metadata_collection_name(metadataCollectionName)
    o_client.set_local_metadata_collection_id(metadataCollectionId)

    o_client.add_cohort_registration(cocoCohort)

    print(f"Configuring {mdr_server}  Access Services (OMAS)....")

    # o_client.configure_all_access_services()
    access_service_options = {
        "SupportedZones": [
            "quarantine",
            "clinical-trials",
            "research",
            "data-lake",
            "trash-can",
        ]
    }

    # o_client.configure_access_service("asset-catalog", access_service_options)
    o_client.configure_access_service("asset-consumer", access_service_options)

    access_service_options["DefaultZones"] = ["quarantine"]
    access_service_options["PublishZones"] = ["data-lake"]

    # print(f"Access Service Options: {access_service_options}")

    o_client.configure_access_service("asset-manager", access_service_options)
    o_client.configure_access_service("asset-owner", access_service_options)
    o_client.configure_access_service("community-profile", {"KarmaPointPlateau": "500"})
    # o_client.configure_access_service("glossary-view", {})
    # o_client.configure_access_service("data-engine", access_service_options)
    o_client.configure_access_service("data-manager", access_service_options)
    o_client.configure_access_service("digital-architecture", access_service_options)
    o_client.configure_access_service("governance-engine", access_service_options)
    o_client.configure_access_service("governance-server", access_service_options)
    o_client.configure_access_service("asset-lineage", access_service_options)

    print(f"Activating {mdr_server}")
    p_client = Platform(mdr_server, platform_url, admin_user)
    p_client.activate_server_stored_config()

    config = o_client.get_stored_configuration()
    print(f"\n\n\tConfiguration of {mdr_server} is complete.")
    print(f"\nThe server stored configuration is:\n {json.dumps(config, indent=4)}")

except Exception as e:
    print_exception_response(e)



"""
SPDX-License-Identifier: Apache-2.0
Copyright Contributors to the ODPi Egeria project.



This module is for testing the glossary manager class and methods
The routines assume that pytest is being used as the test tool and framework.

A running Egeria environment is needed to run these tests.

"""

import asyncio
import json
import time
from contextlib import nullcontext as does_not_raise

import pytest


from pyegeria._exceptions import (
    InvalidParameterException,
    PropertyServerException,
    UserNotAuthorizedException,
    print_exception_response,
)
from pyegeria.asset_catalog_omvs import AssetCatalog
from pyegeria.automated_curation import AutomatedCuration
# from pyegeria.md_processing_utils import print_json_list_as_table

# from pyegeria.admin_services import FullServerConfig

disable_ssl_warnings = True


class TestAssetCatalog:
    good_platform1_url = "https://127.0.0.1:9443"
    good_platform2_url = "https://oak.local:9443"
    bad_platform1_url = "https://localhost:9443"

    # good_platform1_url = "https://127.0.0.1:30080"
    # good_platform2_url = "https://127.0.0.1:30081"
    # bad_platform1_url = "https://localhost:9443"

    good_user_1 = "garygeeke"
    good_user_2 = "erinoverview"
    good_user_3 = "peterprofile"
    bad_user_1 = "eviledna"
    bad_user_2 = ""
    good_integ_1 = "fluffy_integration"
    good_server_1 = "simple-metadata-store"
    good_server_2 = "laz_kv"
    good_server_3 = "active-metadata-store"
    good_server_4 = "integration-daemon"
    good_server_5 = "fluffy_kv"
    good_server_6 = "cocoVIew1"
    good_engine_host_1 = "governDL01"
    good_view_server_1 = "view-server"
    good_view_server_2 = "qs-view-server"
    bad_server_1 = "coco"
    bad_server_2 = ""

    def test_find_in_asset_domain(self):
        try:
            g_client = AssetCatalog(
                self.good_view_server_1,
                self.good_platform1_url,
                user_id=self.good_user_2,
            )

            token = g_client.create_egeria_bearer_token(self.good_user_2, "secret")
            start_time = time.perf_counter()
            search_string = "Unity"
            response = g_client.find_in_asset_domain(
                search_string, starts_with=True, ends_with=False, ignore_case=True
            )
            duration = time.perf_counter() - start_time
            # resp_str = json.loads(response)
            print(f"\n\tDuration was {duration} seconds")
            if type(response) is list:
                # print("\n\n" + json.dumps(response, indent=4))
                count = len(response)
                print(f"Found {count} asset")
                for i in range(count):
                    # print(f"Found asset: {response[i]['glossaryProperties']['qualifiedName']} with id of {response[i]['elementHeader']['guid']}")
                    print(json.dumps(response[i], indent=4))
            elif type(response) is str:
                print("\n\n" + response)
            assert True

        except (
            InvalidParameterException,
            PropertyServerException,
            UserNotAuthorizedException,
        ) as e:
            print_exception_response(e)
            assert False, "Invalid request"
        finally:
            g_client.close_session()

    def test_find_several_in_asset_domain(self):
        try:
            g_client = AssetCatalog(
                self.good_view_server_2,
                self.good_platform1_url,
                user_id=self.good_user_2,
            )

            token = g_client.create_egeria_bearer_token(self.good_user_2, "secret")
            start_time = time.perf_counter()
            asset = ["Set up new clinical trial", "unity", "number", "week"]

            for a in asset:
                start_time = time.perf_counter()
                response = g_client.find_in_asset_domain(
                    a,
                    starts_with=True,
                    ends_with=False,
                    ignore_case=False,
                    time_out=120,
                )
                duration = time.perf_counter() - start_time

                if type(response) is list:
                    # print("\n\n" + json.dumps(response, indent=4))
                    count = len(response)
                    print(f"Found {count} assets for search {a} in {duration} seconds")
                    # for i in range(count):
                    #     # print(f"Found asset: {response[i]['glossaryProperties']['qualifiedName']} with id of {response[i]['elementHeader']['guid']}")
                    #     print(json.dumps(response[i], indent=4))
                elif type(response) is str:
                    print("\n\n" + response)

        except (
            InvalidParameterException,
            PropertyServerException,
            UserNotAuthorizedException,
        ) as e:
            print_exception_response(e)
            assert False, "Invalid request"
        finally:
            g_client.close_session()

    def test_get_asset_graph(self, server: str = good_view_server_1):
        try:
            server_name = server
            asset_guid = "8a578f0d-f7ae-4255-b4a5-236241fa5449"
            a_client = AssetCatalog(
                server_name, self.good_platform1_url, user_id=self.good_user_2
            )

            token = a_client.create_egeria_bearer_token(self.good_user_2, "secret")

            response = a_client.get_asset_graph(asset_guid)
            print(f"type is {type(response)}")
            if type(response) is dict:
                print("\n\n" + json.dumps(response, indent=4))
                count = len(response)
                print(f"Found {count} assets")
            elif type(response) is str:
                print("\n\n" + response)
            assert True
        except (
            InvalidParameterException,
            PropertyServerException,
            UserNotAuthorizedException,
        ) as e:
            print_exception_response(e)
            assert False, "Invalid request"

        finally:
            a_client.close_session()

    def test_get_asset_mermaid_graph(self, server: str = good_view_server_1):
        try:
            server_name = server
            asset_guid = "8a578f0d-f7ae-4255-b4a5-236241fa5449"
            a_client = AssetCatalog(
                server_name, self.good_platform1_url, user_id=self.good_user_2
            )

            token = a_client.create_egeria_bearer_token(self.good_user_2, "secret")

            response = a_client.get_asset_mermaid_graph(asset_guid)
            print(f"type is {type(response)}")
            if type(response) is dict:
                print("\n\n" + json.dumps(response, indent=4))
                count = len(response)
                print(f"Found {count} pieces")
            elif type(response) is str:
                print("\n\n" + response)
            assert True
        except (
            InvalidParameterException,
            PropertyServerException,
            UserNotAuthorizedException,
        ) as e:
            print_exception_response(e)
            assert False, "Invalid request"

        finally:
            a_client.close_session()

    def test_get_asset_lineage_graph(self, server: str = good_view_server_2):
        try:
            server_name = server
            asset_guid = "8a578f0d-f7ae-4255-b4a5-236241fa5449"
            a_client = AssetCatalog(
                server_name, self.good_platform1_url, user_id=self.good_user_2
            )

            token = a_client.create_egeria_bearer_token(self.good_user_2, "secret")

            effective_time = None
            as_of_time = None
            relationship_types = None
            limit_to_isc_q_name = "InformationSupplyChain:Sustainability Reporting"
            hilight_isc_q_name = None

            response = a_client.get_asset_lineage_graph(asset_guid, effective_time,
                                                        as_of_time, relationship_types,
                                                        limit_to_isc_q_name, hilight_isc_q_name,
                                                        )
            print(f"type is {type(response)}")
            if type(response) is dict:
                print("\n\n" + json.dumps(response, indent=4))
                count = len(response)
                print(f"Found {count} pieces")
            elif type(response) is str:
                print("\n\n" + response)
            assert True
        except (
            InvalidParameterException,
            PropertyServerException,
            UserNotAuthorizedException,
        ) as e:
            print_exception_response(e)
            assert False, "Invalid request"

        finally:
            a_client.close_session()

    def test_get_asset_lineage_mermaid_graph(self, server: str = good_view_server_1):
        try:
            server_name = server
            asset_guid = "8a578f0d-f7ae-4255-b4a5-236241fa5449"
            a_client = AssetCatalog(
                server_name, self.good_platform1_url, user_id=self.good_user_2
            )

            token = a_client.create_egeria_bearer_token(self.good_user_2, "secret")

            response = a_client.get_asset_lineage_mermaid_graph(asset_guid)
            print(f"type is {type(response)}")
            if type(response) is dict:
                print("\n\n" + json.dumps(response, indent=4))
                count = len(response)
                print(f"Found {count} pieces")
            elif type(response) is str:
                print("\n\n" + response)
            assert True
        except (
            InvalidParameterException,
            PropertyServerException,
            UserNotAuthorizedException,
        ) as e:
            print_exception_response(e)
            assert False, "Invalid request"

        finally:
            a_client.close_session()

    def test_get_assets_by_metadata_collection_id(
        self, server: str = good_view_server_1
    ):
        try:
            server_name = server
            metadata_collection_id = (
                "74a786b2-d6d7-401d-b8c1-7d798f752c55"  # Coco Template Archive
            )
            a_client = AssetCatalog(
                server_name, self.good_platform1_url, user_id=self.good_user_2
            )

            token = a_client.create_egeria_bearer_token(self.good_user_2, "secret")

            response = a_client.get_assets_by_metadata_collection_id(
                metadata_collection_id, "SoftwareServer"
            )
            print(f"type is {type(response)}")
            if type(response) is list:
                print("\n\n" + json.dumps(response, indent=4))
                count = len(response)
                print(f"Found {count} terms")
            elif type(response) is str:
                print("\n\n" + response)
            assert True
        except (
            InvalidParameterException,
            PropertyServerException,
            UserNotAuthorizedException,
        ) as e:
            print_exception_response(e)
            assert False, "Invalid request"

        finally:
            a_client.close_session()

    def test_get_asset_catalog_types(self, server: str = good_view_server_1):
        try:
            server_name = server
            a_client = AssetCatalog(
                server_name, self.good_platform1_url, user_id=self.good_user_2
            )

            token = a_client.create_egeria_bearer_token(self.good_user_2, "secret")

            response = a_client.get_asset_types()
            print(f"type is {type(response)}")
            if type(response) is list:
                print("\n\n" + json.dumps(response, indent=4))
                count = len(response)
                print(f"Found {count} terms")
            elif type(response) is str:
                print("\n\n" + response)
            assert True
        except (
            InvalidParameterException,
            PropertyServerException,
            UserNotAuthorizedException,
        ) as e:
            print_exception_response(e)
            assert False, "Invalid request"

        finally:
            a_client.close_session()

    def test_create_folder_asset_body(self, server: str = good_view_server_1):
        try:
            server_name = server
            a_client = AssetCatalog(
                server_name, self.good_platform1_url, user_id=self.good_user_2
            )
            b_client = AutomatedCuration(server_name, self.good_platform1_url, user_id=self.good_user_2)


            token = a_client.create_egeria_bearer_token(self.good_user_2, "secret")
            token = b_client.create_egeria_bearer_token(self.good_user_2, "secret")
            file_folder_template_guid = b_client.get_template_guid_for_technology_type(
                "FileFolder template"
            )
            body = {
                "templateGUID": file_folder_template_guid,
                "isOwnAnchor": True,
                "placeholderPropertyValues": {
                    "clinicalTrialId": "TransMorg-1",
                    "clinicalTrialName": "TransMorgification",
                    "hospitalName": "Bedlam",
                    "deployedImplementationType": "FileFolder",
                    "fileSystemName": "Bedlam-Hospital-Systems",
                    "directoryName": "TransMorg-Clinical-Trials-Weeklies",
                    "directoryPathName": "Dungeon/lab",
                    "contactName": "Dr Jekyll",
                    "contactDept": "Pharmacology",
                    "dateReceived": "23-06-24",
                    "description": "Clinical trial data folder",
                },
            }

            response = a_client.create_element_from_template(body)
            print(f"type is {type(response)}")
            if type(response) is dict:
                print("\n\n" + json.dumps(response, indent=4))
                count = len(response)
                print(f"Found {count} terms")
            elif type(response) is str:
                print("\n\n" + response)
            assert True
        except (
            InvalidParameterException,
            PropertyServerException,
            UserNotAuthorizedException,
        ) as e:
            print_exception_response(e)
            assert False, "Invalid request"

        finally:
            a_client.close_session()



#!/usr/bin/env python3
"""
SPDX-License-Identifier: Apache-2.0
Copyright Contributors to the ODPi Egeria project.


Retrieve anchored elements based on a search of a specified properties.
"""
import argparse
import os
import sys
import time

from rich import box
from rich.console import Console
from rich.markdown import Markdown
from rich.prompt import Prompt
from rich.table import Table

from pyegeria import (
    EgeriaTech,
    InvalidParameterException,
    PropertyServerException,
    UserNotAuthorizedException,
    print_exception_response,
)

EGERIA_METADATA_STORE = os.environ.get("EGERIA_METADATA_STORE", "active-metadata-store")
EGERIA_KAFKA_ENDPOINT = os.environ.get("KAFKA_ENDPOINT", "localhost:9092")
EGERIA_PLATFORM_URL = os.environ.get("EGERIA_PLATFORM_URL", "https://localhost:9443")
EGERIA_VIEW_SERVER = os.environ.get("EGERIA_VIEW_SERVER", "view-server")
EGERIA_VIEW_SERVER_URL = os.environ.get(
    "EGERIA_VIEW_SERVER_URL", "https://localhost:9443"
)
EGERIA_INTEGRATION_DAEMON = os.environ.get("EGERIA_INTEGRATION_DAEMON", "integration-daemon")
EGERIA_ADMIN_USER = os.environ.get("ADMIN_USER", "garygeeke")
EGERIA_ADMIN_PASSWORD = os.environ.get("ADMIN_PASSWORD", "secret")
EGERIA_USER = os.environ.get("EGERIA_USER", "erinoverview")
EGERIA_USER_PASSWORD = os.environ.get("EGERIA_USER_PASSWORD", "secret")
EGERIA_JUPYTER = bool(os.environ.get("EGERIA_JUPYTER", "False"))
EGERIA_WIDTH = int(os.environ.get("EGERIA_WIDTH", "260"))


disable_ssl_warnings = True


def display_anchored_elements(
    property_value: str,
    prop_list: list[str],
    server: str,
    url: str,
    username: str,
    user_password: str,
    time_out: int = 60,
    jupyter: bool = EGERIA_JUPYTER,
    width: int = EGERIA_WIDTH,
):
    console = Console(width=width, force_terminal=not jupyter, soft_wrap=True)
    if (property_value is None) or (len(property_value) < 3):
        print(
            "\nError --> Invalid Search String - must be greater than four characters long"
        )
        sys.exit(3)
    g_client = EgeriaTech(server, url, username, user_password)
    token = g_client.create_egeria_bearer_token()
    print(f"search value is {property_value} and prop_list is {prop_list}\n")

    def generate_table(property_value: str, prop_list: [str]) -> Table:
        """Make a new table."""
        table = Table(
            title=f"Elements containing the string  {property_value} @ {time.asctime()}",
            header_style="white on dark_blue",
            style="bold white on black",
            row_styles=["bold white on black"],
            title_style="bold white on black",
            caption_style="white on black",
            show_lines=True,
            box=box.ROUNDED,
            caption=f"View Server '{server}' @ Platform - {url}",
            expand=True,
        )
        # table.add_column("Qualified Name")
        table.add_column("GUID", no_wrap=True)
        table.add_column("Properties")

        table.add_column("Classification Props", width=30)
        table.add_column("Matching Elements")

        classification = "Anchors"
        open_type_name = None
        property_value = property_value

        property_names = prop_list

        elements = g_client.find_elements_by_classification_with_property_value(
            classification, property_value, property_names, open_type_name
        )
        if type(elements) is str:
            return table

        for element in elements:
            template = False
            guid = element["elementHeader"].get("guid", "---")
            classifications = element["elementHeader"]["classifications"]

            class_prop_md = ""
            for classific in classifications:
                class_prop = classific.get("classificationProperties", "---")
                if type(class_prop) is dict:
                    for key in class_prop.keys():
                        class_prop_md += f"* {key}: {class_prop[key]}\n"

            class_prop_out = Markdown(class_prop_md)

            properties = element["properties"]
            props_md = ""
            if type(properties) is dict:
                for key in properties.keys():
                    props_md += f"* {key}: {properties[key]}\n"
                    if key == "category" and properties[key] == "placeholderProperty":
                        template = True
            props_out = Markdown(props_md)

            if template:  # Not interested in template elements in this method
                continue

            relationship = g_client.get_related_elements(guid, None, None)

            if type(relationship) is list:
                rel_md = ""
                for rel in relationship:
                    match_tab = Table(expand=True)
                    match_tab.add_column("Type Name")
                    match_tab.add_column("GUID", no_wrap=True, width=36)
                    match_tab.add_column("Properties")
                    match = rel["relationshipHeader"]
                    match_type_name = match["type"]["typeName"]
                    matching_guid = match["guid"]
                    match_props = rel["relatedElement"]["properties"]
                    match_details_md = ""
                    for key in match_props.keys():
                        match_details_md += f"* {key}: {match_props[key]}\n"
                    match_details_out = Markdown(match_details_md)
                    match_tab.add_row(match_type_name, matching_guid, match_details_out)

            table.add_row(guid, props_out, class_prop_out, match_tab)

        g_client.close_session()
        return table

    try:
        with console.pager(styles=True):
            console.print(generate_table(property_value, prop_list), soft_wrap=True)

    except (
        InvalidParameterException,
        PropertyServerException,
        UserNotAuthorizedException,
    ) as e:
        console.print_exception()
        sys.exit(1)

    except Exception as e:
        console.print(
            f"\n\n====> Invalid Search String - must be greater than four characters long"
        )
        sys.exit(1)


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("--server", help="Name of the server to display status for")
    parser.add_argument("--url", help="URL Platform to connect to")
    parser.add_argument("--userid", help="User Id")
    parser.add_argument("--password", help="User Password")
    parser.add_argument("--time_out", help="Time Out")

    args = parser.parse_args()

    server = args.server if args.server is not None else EGERIA_VIEW_SERVER
    url = args.url if args.url is not None else EGERIA_PLATFORM_URL
    userid = args.userid if args.userid is not None else EGERIA_USER
    user_pass = args.password if args.password is not None else EGERIA_USER_PASSWORD
    time_out = args.time_out if args.time_out is not None else 60
    try:
        property_value = Prompt.ask("Enter an property search string:", default="")
        prop_list = Prompt.ask(
            "Enter the list of properties to search", default="anchorTypeName"
        )
        if property_value == "":
            print("\nError --> Search string can't be empty")
            sys.exit(1)
        elif len(property_value) <= 4:
            print("\nError --> Search string must be greater than four characters long")
            sys.exit(2)
        else:
            display_anchored_elements(
                property_value, [prop_list], server, url, userid, user_pass, time_out
            )
    except KeyboardInterrupt:
        pass


if __name__ == "__main__":
    main()



"""
SPDX-License-Identifier: Apache-2.0
Copyright Contributors to the ODPi Egeria project.



pyegeria md_commands available also from python.
"""
from .cat.dr_egeria_md import process_markdown_file
from .cat.list_deployed_catalogs import list_deployed_catalogs
from .cat.list_deployed_database_schemas import list_deployed_database_schemas
from .cat.list_deployed_databases import list_deployed_databases
from .cat.list_glossaries import display_glossaries
from .cat.list_terms import display_glossary_terms
from .ops.list_catalog_targets import display_catalog_targets
from .ops.monitor_engine_activity_c import display_engine_activity_c
from .ops.monitor_gov_eng_status import display_gov_eng_status
from .ops.monitor_integ_daemon_status import display_integration_daemon_status
from .ops.table_integ_daemon_status import (
    display_integration_daemon_status as table_integ_daemon_status,
)
from .tech.list_elements_by_property_value import EGERIA_WIDTH


def list_integration_daemon_status(
    search_list: str, width: int = EGERIA_WIDTH, sort: bool = True
):
    table_integ_daemon_status(
        search_list=search_list, paging=True, width=width, sort=sort
    )



"""
SPDX-License-Identifier: Apache-2.0
Copyright Contributors to the ODPi Egeria project.



Egeria Coco Pharmaceutical demonstration labs.

This script creates and configures the cocoMDS3 - Research server.

"""

import json

from globals import cocoCohort, cocoMDS3Name, corePlatformURL, max_paging_size

from pyegeria import print_exception_response
from pyegeria.core_omag_server_config import CoreServerConfig
from pyegeria.platform_services import Platform

mdr_server = cocoMDS3Name
platform_url = corePlatformURL
admin_user = "garygeeke"
mdr_server_user_id = "cocoMDS3npa"
mdr_server_password = "cocoMDS3passw0rd"
metadataCollectionId = f"{mdr_server}-e915f2fa-aa3g-4396-8bde-bcd65e642b1d"
metadataCollectionName = "Research Catalog"

print("Configuring " + mdr_server + "...")
try:
    o_client = CoreServerConfig(mdr_server, platform_url, admin_user)

    o_client.set_basic_server_properties(
        "Research Server",
        "Coco Pharmaceuticals",
        platform_url,
        mdr_server_user_id,
        mdr_server_password,
        max_paging_size,
    )

    # Can inherit event bus config

    # event_bus_config = {
    #     "producer": {
    #         "bootstrap.servers": "localhost:9092"
    #     },
    #     "consumer": {
    #         "bootstrap.servers": "localhost:9092"
    #     }
    # }
    #
    # o_client.set_event_bus(event_bus_config)

    security_connection_body = {
        "class": "Connection",
        "connectorType": {
            "class": "ConnectorType",
            "connectorProviderClassName": "org.odpi.openmetadata.metadatasecurity.samples.CocoPharmaServerSecurityProvider",
        },
    }
    o_client.set_server_security_connection(security_connection_body)
    o_client.add_default_log_destinations()

    # o_client.set_in_mem_local_repository()
    o_client.set_xtdb_local_kv_repository()

    o_client.set_local_metadata_collection_id(metadataCollectionId)
    o_client.set_local_metadata_collection_name(metadataCollectionName)

    o_client.add_cohort_registration(cocoCohort)

    print(f"Configuring {mdr_server}  Access Services (OMAS)....")

    access_service_options = {
        "SupportedZones": [
            "personal-files",
            "clinical-trials",
            "research",
            "data-lake",
            "trash-can",
        ]
    }
    # o_client.configure_access_service("asset-catalog", access_service_options)
    o_client.configure_access_service("asset-consumer", access_service_options)

    access_service_options["DefaultZones"] = ["personal-files"]

    o_client.configure_access_service("asset-owner", access_service_options)
    o_client.configure_access_service("community-profile", {"KarmaPointPlateau": "500"})
    # o_client.configure_access_service("glossary-view", {})
    o_client.configure_access_service("data-science", {})
    # o_client.configure_access_service("subject-area", {})
    o_client.configure_access_service("asset-manager", access_service_options)
    o_client.configure_access_service("governance-engine", access_service_options)
    o_client.configure_access_service("governance-server", access_service_options)

    o_client.configure_access_service("project-management", access_service_options)

    p_client = Platform(mdr_server, platform_url, admin_user)
    p_client.activate_server_stored_config()

    print(f"\n\n\tConfiguration of {mdr_server} is complete.")

    config = o_client.get_stored_configuration()
    print(f"The server stored configuration is \n{json.dumps(config, indent=4)}")

except Exception as e:
    print_exception_response(e)



"""
SPDX-License-Identifier: Apache-2.0
Copyright Contributors to the ODPi Egeria project.

This is the pyegeria client package. The purpose of the package is to provide
easy access to Egeria (https://egeria-project.org). The package is currently in
development.

The first capabilities are around Egeria's platform services used to start and stop
the server platform and servers.

"""
# from .load_config import load_app_config, get_app_config
# from .logging_configuration import config_logging, init_logging
from ._globals import (default_time_out, disable_ssl_warnings, enable_ssl_check,
                       is_debug, max_paging_size, NO_ELEMENTS_FOUND, NO_ASSETS_FOUND, NO_SERVERS_FOUND,
                       NO_CATALOGS_FOUND, NO_GLOSSARIES_FOUND, NO_TERMS_FOUND, NO_CATEGORIES_FOUND, NO_ELEMENT_FOUND,
                       NO_PROJECTS_FOUND, DEBUG_LEVEL, NO_COLLECTION_FOUND, NO_GUID_RETURNED, COMMENT_TYPES
                       )



if disable_ssl_warnings:
    from urllib3 import disable_warnings
    from urllib3.exceptions import InsecureRequestWarning

    disable_warnings(InsecureRequestWarning)

from ._client import Client
from ._client_new import Client2
from ._exceptions_new import (PyegeriaInvalidParameterException,PyegeriaAPIException, PyegeriaException,
                              PyegeriaUnauthorizedException, PyegeriaClientException, PyegeriaUnknownException,
                              PyegeriaConnectionException, PyegeriaNotFoundException,
                              print_exception_table, print_basic_exception, print_validation_error)
from .config import load_app_config, get_app_config, settings
from .logging_configuration import config_logging, console_log_filter, init_logging
from ._exceptions import (InvalidParameterException, PropertyServerException, UserNotAuthorizedException,
                          print_exception_response, )
from ._validators import (is_json, validate_guid, validate_name, validate_public, validate_search_string,
                          validate_server_name, validate_url, validate_user_id, )
from .asset_catalog_omvs import AssetCatalog
from .automated_curation import AutomatedCuration
from .classification_manager_omvs import ClassificationManager
from .collection_manager import CollectionManager
from .core_omag_server_config import CoreServerConfig
from .create_tech_guid_lists import build_global_guid_lists
from .egeria_cat_client import EgeriaCat
from .egeria_client import Egeria
from .egeria_config_client import EgeriaConfig

from .egeria_tech_client import EgeriaTech
# from .feedback_manager_omvs import FeedbackManager
from .full_omag_server_config import FullServerConfig
from .glossary_manager import GlossaryManager
from .governance_officer import GovernanceOfficer
from .mermaid_utilities import (construct_mermaid_web, construct_mermaid_jup,  load_mermaid,
                                parse_mermaid_code, render_mermaid, save_mermaid_graph, save_mermaid_html, )
from .metadata_explorer_omvs import MetadataExplorer
from .my_profile_omvs import MyProfile
from .platform_services import Platform
from .project_manager import ProjectManager
from .registered_info import RegisteredInfo
from .runtime_manager_omvs import RuntimeManager
from .server_operations import ServerOps
from .solution_architect import SolutionArchitect
from .utils import body_slimmer,to_pascal_case, to_camel_case, camel_to_title_case
from .valid_metadata_omvs import ValidMetadataManager
from .x_action_author_omvs import ActionAuthor
from .template_manager_omvs import TemplateManager
from .data_designer import DataDesigner
from ._output_formats import select_report_spec
from .mcp_adapter import list_reports, describe_report, run_report, _async_run_report, _execute_egeria_call_blocking

#
# 2/12/25

def __getattr__(name):
    """
    Lazy attribute loader to avoid import-time circular dependencies while preserving API.
    Exposes:
    - process_markdown_file via commands.cat.dr_egeria_md
    - md_processing package
    - commands package
    """
    if name == "process_markdown_file":
        from commands.cat.dr_egeria_md import process_markdown_file as _pmf
        return _pmf
    if name == "md_processing":
        import md_processing as _mdp
        return _mdp
    if name == "commands":
        import commands as _cmd
        return _cmd
    raise AttributeError(f"module 'pyegeria' has no attribute {name!r}")

if __name__ == "__main__":
    print("Main-Init")
